//////////////////////////////////////////////////////////////////////
//
// File:     DCComp.java
// Project:  MIE457F Data Mining System
// Author:   Scott Sanner, University of Toronto (ssanner@cs.toronto.edu)
// Date:     10/1/2003
//
//////////////////////////////////////////////////////////////////////

// Package definition
package dm.datacube;

// Packages to import
import java.util.*;

/**
 * Implements an object for identifying internal datacube structure
 *
 * @version   1.0
 * @author    Scott Sanner
 * @language  Java (JDK 1.3)
 **/
public class DCComp     
    implements Comparator {

    /** Local data members **/
    public ArrayList _alCompOrder;
    public HashMap   _hmRestrictions;

    /** Constructor
     *  @param comparison_order The order in which to sort indices in
     *                          the data cube (contains Integers).
     **/
    public DCComp(ArrayList comparison_order) {
	_hmRestrictions = new HashMap();
	_alCompOrder = comparison_order;

	// Verify all indices are Integers!
	Iterator i = _alCompOrder.iterator();
	while (i.hasNext()) {
	    if ( !(i.next() instanceof Integer) ) {
		System.out.println("DataCube comparator must have Integer indices!");
		System.exit(1);
	    }
	}
    }

    /** The Comparator compare(...) implementation
     *  @param o1 First object in comparison
     *  @param o2 Second object in comparison
     *  @return (-1) if o1<o2, (1) if o1>o2, (0) if equal
     **/
    public int compare(Object o1, Object o2) {

	// Cast to the expected objects
	DataCube.DataElement de1 = (DataCube.DataElement)o1;
	DataCube.DataElement de2 = (DataCube.DataElement)o2;

	// Compare the DataElement key values in the order given by
	// _alRestrOrder, proceeding to the next key if the current
	// keys are equal.  Continue until a non-zero comparison found
	// or all key values equal.
	Iterator i = _hmRestrictions.keySet().iterator();
	while (i.hasNext()) {
	    Integer index = (Integer)i.next();
	    Integer value = (Integer)_hmRestrictions.get(index);
	    int ind = index.intValue();
	    int comp_val = de1._key[ind].compareTo(de2._key[ind]);
	    if (comp_val != 0) {
		return comp_val;
	    }
	}	

	// Now compare the DataElement key values in the order given by
	// _alCompOrder, proceeding to the next key if the current
	// keys are equal.  Continue until a non-zero comparison found
	// or all key values equal.
	i = _alCompOrder.iterator();
	while (i.hasNext()) {
	    int index    = ((Integer)i.next()).intValue();
	    int comp_val = de1._key[index].compareTo(de2._key[index]);
	    if (comp_val != 0) {
		return comp_val;
	    }
	}

	return (0); // Must be the same
    }

    /** Add a dimension for comparison
     *  @param index Index to add
     **/
    public void addRestriction(Integer dim_index, Integer value) {

	// Add dim to comparison order if not already there
	if (!_hmRestrictions.containsKey(dim_index) && 
	    _alCompOrder.indexOf(dim_index) < 0) {
	    _hmRestrictions.put(dim_index, value);
	}
    }

    /** Drop a dimension from the comparison
     *  @param index Index to drop
     **/
    public void dropRestriction(Integer dim_index) {

	// Remove dim from comparison order if in list
	if (_hmRestrictions.containsKey(dim_index)) {
	    _hmRestrictions.remove(dim_index);
	}
    }

    /** Add a dimension for comparison
     *  @param index Index to add
     **/
    public void addDim(Integer dim_index) {

	// Add dim to comparison order if not already there
	if (_alCompOrder.indexOf(dim_index) < 0 && !_hmRestrictions.containsKey(dim_index)) {
	    _alCompOrder.add(dim_index);
	}
    }

    /** Drop a dimension from the comparison
     *  @param index Index to drop
     **/
    public void dropDim(Integer dim_index) {

	// Remove dim from comparison order if in list
	if (_alCompOrder.indexOf(dim_index) >= 0) {
	    _alCompOrder.remove(dim_index);
	}
    }

    /** Just a way to determine if two Comparators enforce
     *  the same ordering.
     *  @param obj Comparator to determine if equal to
     **/
    public boolean equals(Object obj) {
	return (this == obj);
    }

}
