//////////////////////////////////////////////////////////////////////
//
// File:     Dimension.java
// Project:  MIE457F Data Mining System
// Author:   Scott Sanner, University of Toronto (ssanner@cs.toronto.edu)
// Date:     10/1/2003
//
//////////////////////////////////////////////////////////////////////

// Package definition
package dm.datacube;

// Packages to import
import java.util.*;

/**
 * Represents and stores dimension data
 *
 * @version   1.0
 * @author    Scott Sanner
 * @language  Java (JDK 1.3)
 **/
public class Dimension {

    /** Local data members **/
    public String  _sDimName;
    public int     _nIndex;           // The corresponding key index for the
                                      // associated data cube (assigned by DataCube)
    public TreeMap _tmDimKey2DimData; // Maps dim keys to attributes

    /** Constructor
     *  @param dim_name Name of this dimension
     **/
    public Dimension(String dim_name) {
	_nIndex   = -1; // Assigned by DataCube
	_sDimName = dim_name;
	_tmDimKey2DimData = new TreeMap();
    }

    /** Add a new dimension key and data
     *  @param key The Integer key used in the database
     *  @param val The list of non-key column data
     **/
    public void addDimData(Integer key, ArrayList val) {
	_tmDimKey2DimData.put(key, val);
    }

    /** Retrieve all keys for this dimension
     *  @return Set of Integers (representing dim keys)
     **/
    public Set getDimKeys() {
	return _tmDimKey2DimData.keySet();
    }
    
    /** Get String representation of a key value
     *  @param  key The dimension to key to get the String for
     *  @return The String representation
     **/
    public String getStringVal(Integer key) {
	ArrayList val = (ArrayList)_tmDimKey2DimData.get(key);
	if (val.size() == 0) {
	    return key.toString();
	} else {
	    return val.toString();
	}
    }

    /** Get the indices for this dimension
     *  @return Set of Integer indices
     **/
    public Set getIndices() {
	return _tmDimKey2DimData.keySet();
    }

    /** Returns the dimension name
     *  @return Dimension name
     **/
    public String toString() {
	return _sDimName;
    }
}
