//////////////////////////////////////////////////////////////////////
//
// File:     Token.java
// Project:  MIE457F Data Mining System
// Author:   Scott Sanner, University of Toronto (ssanner@cs.toronto.edu)
// Date:     10/1/2003
//
//////////////////////////////////////////////////////////////////////

// Package definition
package dm.dmql;

// Packages to import
import java.io.*;
import java.lang.*;
import java.util.*;

/**
 * A generic token structure for TokenStream
 *
 * @version   1.0
 * @author    Scott Sanner
 * @language  Java (JDK 1.3)
 **/
public class Token
{
    // Note: We could add more information to a token such as
    // its type (e.g., symbol, number, string, etc...) but
    // this structure suffices for an initial implementation.

    /** Data members **/
    public String _sToken;     // String associated with a token
    public int    _nPos;       // Character position in file (absolute)
    public int    _nLine;      // Line number in file
    public int    _nLinePos;   // Char position on current line

    /** Constructor
     *  @param token    String associated with token
     *  @param pos      Absolute char position in file
     *  @param line     Absolute line position in a file
     *  @param line_pos Char position relative to line
     **/
    public Token(String token, int pos, int line, int line_pos) {
	//System.out.println("Token: " + token);
	_sToken     = token;
	_nPos       = pos;
	_nLine      = line;
	_nLinePos   = line_pos;
    }

    /** Get string for class
     *  @return String representing class contents
     **/
    public String toString() {
	return "<'" + _sToken + "', Pos:" + _nPos + ", Line:" + 
	    _nLine + ", LinePos:" + _nLinePos + ">";
    }
}
