/////////////////////////////////////////////////////////////////////////
//
// File:     TokenStream.java
// Project:  MIE457F Data Mining System
// Author:   Scott Sanner, University of Toronto (ssanner@cs.toronto.edu)
// Date:     10/1/2003
//
// Notes: Supports primitive top-down parsing with match(String str) and 
// next token lookahead nextTokenEquals(String str).
//
/////////////////////////////////////////////////////////////////////////

// Package definition
package dm.dmql;

// Packages to import
import java.lang.*;
import java.net.*;

/**
 * A generic tokenizer interface
 *
 * @version   1.0
 * @author    Scott Sanner
 * @language  Java (JDK 1.3)
 **/
public interface TokenStream
{
    /** Opens the TokenStream given a string to process
     *  @param str The String to process
     **/
    public void process(String str) throws TokenStreamException;

    /** Closes the TokenStream
     **/
    public void close() throws TokenStreamException;

    /** Attempts to match the next token, throws TokenStreamException 
     *  @param content String to match next token against
     **/
    public void match(String content) throws TokenStreamException;

    /** Determines if the next token is the specified String
     *  @param  str  The String to be compared against
     *  @return true if next token is equal to str
     **/
    public boolean nextTokenEquals(String str) throws TokenStreamException;

    /** Returns the next Token from a TokenStream or null
     *  if the end of the stream has been reached.  Throws
     *  a TokenStreamException if there is an IO error.
     *  @return The next token or null (if no tokens remain)
     **/    
    public Token nextToken() throws TokenStreamException;
}
