///////////////////////////////////////////////////////////////////////
//
// File:     ClassificationProc.java
// Project:  MIE457F Data Mining System
// Author:   Scott Sanner, University of Toronto (ssanner@cs.toronto.edu)
// Date:     10/1/2003
//
// Description:
//
//   Defines the interface for a Classification Procedure defined by
//   a DMQL.FindClassRules command and operating on a DataCube object.
//
////////////////////////////////////////////////////////////////////////

// Package definition
package dm.mine;

// Packages to import
import dm.dmql.*;
import dm.datacube.*;
import java.util.*;

/**
 * Defines interface for a Classification Procedure
 *
 * @version   1.0
 * @author    Scott Sanner
 * @language  Java (JDK 1.3)
 **/
public interface ClassificationProc {

    /** Perform a data mining procedure to find classification rules
     *  according to the parameters of com and operating on a
     *  DataCube.
     *
     *  @param  com The command defining the paramters of this 
     *              classification procedure
     *  @param  d   The datacube to mine
     *  @return A List object containing rules.  The type of this
     *          object is undefined.  At the very least, it must simply
     *          implement the toString() method so that it's rule
     *          contents can be displayed for the user.
     **/
    public List mineClassRules(DMQL.FindClassRules com, DataCube d);
    
}
